netutil

package
v0.26.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 1, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseCIDR

func ParseCIDR(cidr string) (*net.IPNet, error)

func SplitHostZone

func SplitHostZone(s string) (host, zone string)

func StripHostPort

func StripHostPort(h string) string

StripHostPort returns h without any trailing ":<port>". It also removes trailing period in the hostname. Per RFC 3696, The DNS specification permits a trailing period to be used to denote the root, e.g., "a.b.c" and "a.b.c." are equivalent, but the latter is more explicit and is required to be accepted by applications. Note that FQDN does not play well with TLS (see https://github.com/traefik/traefik/issues/9157#issuecomment-1180588735)

Types

This section is empty.

Jump to