Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EqualASCIIIgnoreCase ¶
EqualASCIIIgnoreCase performs case-insensitive comparison of two ASCII bytes. Only supports ASCII letters (A-Z, a-z), digits (0-9), hyphen (-) and underscore (_). Used for hostname matching where registered routes follow LDH standard.
func EqualStringsASCIIIgnoreCase ¶
EqualStringsASCIIIgnoreCase performs case-insensitive comparison of two strings containing ASCII characters. Only supports ASCII letters (A-Z, a-z), digits (0-9), hyphen (-) and underscore (_). Used for hostname matching where registered routes follow LDH standard.
func ToLowerASCII ¶
ToLowerASCII converts an ASCII uppercase letter (A-Z) to lowercase (a-z). All other bytes are returned unchanged. Does not validate ASCII range;
Types ¶
This section is empty.