Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SplitHostZone ¶
func StripHostPort ¶
StripHostPort returns h without any trailing ":<port>". It also removes trailing period in the hostname. Per RFC 3696, The DNS specification permits a trailing period to be used to denote the root, e.g., "a.b.c" and "a.b.c." are equivalent, but the latter is more explicit and is required to be accepted by applications. Note that FQDN does not play well with TLS (see https://github.com/traefik/traefik/issues/9157#issuecomment-1180588735)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.